@@ -34,6 +34,9 @@
 /* Define the Dosemu version */
 #undef VERSION
 
+/* Define the Dosemu version release date */
+#undef VERDATE
+
 /* Define the Dosemu sublevel */
 #undef SUBLEVEL
 
@@ -71,7 +74,7 @@
 #undef REQUIRES_VM86PLUS
 
 /* DEFINE this, if you have vm86plus built into the kernel */
-#undef BUILTIN_VMP86PLUS
+#undef BUILTIN_VM86PLUS
 
 /* DPMI test windows */
 #undef WANT_WINDOWS
@@ -86,6 +89,9 @@
 /* Add if you have X-Keycode problems */
 #undef NEW_KEYCODES
 
+/* Define this to use the new keyboard code */
+#undef NEW_KBD_CODE
+
 /*
  *  DEFINE this, if you have joystick support in the kernel
  *  or have the joystick module loaded (needing <linux/joystick.h>)
@@ -101,6 +107,15 @@
 /* Define this if you want to use MITSHM */
 #undef HAVE_MITSHM
 
+/* Define this if you want to use a monoton micro timing (Bernd Paysan) */
+#undef MONOTON_MICRO_TIMING
+
+/* Define this if you want dosemu permanently run as (suid) root and only gain
+ * user privileges, when accessing secure relevant resources.
+ * Otherwise dosemu will permanently run as user and only temporary take over
+ * root privilege when needed.
+ */
+#undef RUN_AS_ROOT
 
 @BOTTOM@
 
